vertical property
A double that defaults to 1.0 that scales Foil data.
In the case of a Foil constructor, that means scaling the computed
accelerometer sensor data, either up or down.
This provides the opportunity to nullify an axis of influence, increase or decrease the influence of an axis, or even reverse one's impact.
In terms of Roll construction, a Scalar object provides a means
to direct animation of the gradient if isAnimated is true.
Also see the min and max values.
Implementation
final double horizontal, vertical;